@@ -1,7 +1,8 @@
 """Generates a df with feature descriptions for the predictors in the source
 df."""
-
+from collections.abc import Sequence
 from pathlib import Path
+from typing import Union
 
 import numpy as np
 import pandas as pd
@@ -11,7 +12,12 @@ from psycop_feature_generation.data_checks.utils import save_df_to_pretty_html_t
 from psycop_feature_generation.loaders.flattened.local_feature_loaders import (
     load_split_predictors,
 )
-from psycop_feature_generation.utils import generate_feature_colname
+from psycop_feature_generation.timeseriesflattener.feature_spec_objects import (
+    AnySpec,
+    PredictorSpec,
+    StaticSpec,
+    TemporalSpec,
+)
 
 UNICODE_HIST = {
     0: " ",
@@ -84,51 +90,79 @@ def create_unicode_hist(series: pd.Series) -> pd.Series:
     return ucode_to_print
 
 
-def generate_feature_description_row(
+def generate_temporal_feature_description(
     series: pd.Series,
-    predictor_dict: dict[str, str],
-) -> dict:
-    """Generate a row with feature description.
-
-    Args:
-        series (pd.Series): Series with data to describe.
-        predictor_dict (dict[str, str]): dictionary with predictor information.
-
-    Returns:
-        dict: dictionary with feature description.
-    """
-
+    predictor_spec: TemporalSpec,
+):
+    """Generate a row with feature description for a temporal predictor."""
     d = {
-        "Predictor df": predictor_dict["predictor_df"],
-        "Lookbehind days": predictor_dict["lookbehind_days"],
-        "Resolve multiple": predictor_dict["resolve_multiple"],
+        "Predictor df": predictor_spec.feature_name,
+        "Lookbehind days": predictor_spec.interval_days,
+        "Resolve multiple": predictor_spec.resolve_multiple_fn,
         "N unique": series.nunique(),
-        "Fallback strategy": predictor_dict["fallback"],
+        "Fallback strategy": predictor_spec.fallback,
         "Proportion missing": series.isna().mean(),
         "Mean": round(series.mean(), 2),
         "Histogram": create_unicode_hist(series),
         "Proportion using fallback": get_value_proportion(
             series,
-            predictor_dict["fallback"],
+            predictor_spec.fallback,
         ),
     }
 
     for percentile in (0.01, 0.25, 0.5, 0.75, 0.99):
         # Get the value representing the percentile
-        d[f"{percentile*100}-percentile"] = round(series.quantile(percentile), 1)
+        d[f"{percentile * 100}-percentile"] = round(series.quantile(percentile), 1)
+
+    return d
+
+
+def generate_static_feature_description(series: pd.Series, predictor_spec: StaticSpec):
+    """Generate a row with feature description for a static predictor."""
+    return {
+        "Predictor df": predictor_spec.feature_name,
+        "Lookbehind days": "N/A",
+        "Resolve multiple": "N/A",
+        "N unique": series.nunique(),
+        "Fallback strategy": "N/A",
+        "Proportion missing": series.isna().mean(),
+        "Mean": round(series.mean(), 2),
+        "Histogram": create_unicode_hist(series),
+        "Proportion using fallback": "N/A",
+    }
+
+
+def generate_feature_description_row(
+    series: pd.Series,
+    predictor_spec: AnySpec,
+) -> dict:
+    """Generate a row with feature description.
+
+    Args:
+        series (pd.Series): Series with data to describe.
+        predictor_spec (PredictorSpec): Predictor specification.
+
+    Returns:
+        dict: dictionary with feature description.
+    """
+
+    if isinstance(predictor_spec, StaticSpec):
+        d = generate_static_feature_description(series, predictor_spec)
+    elif isinstance(predictor_spec, TemporalSpec):
+        d = generate_temporal_feature_description(series, predictor_spec)
 
     return d
 
 
 def generate_feature_description_df(
     df: pd.DataFrame,
-    predictor_dicts: list[dict[str, str]],
+    predictor_specs: list[PredictorSpec],
 ) -> pd.DataFrame:
     """Generate a data frame with feature descriptions.
 
     Args:
         df (pd.DataFrame): Data frame with data to describe.
-        predictor_dicts (list[dict[str, str]]): list of dictionaries with predictor information.
+        predictor_specs (PredictorSpec): Predictor specifications.
 
     Returns:
         pd.DataFrame: Data frame with feature descriptions.
@@ -136,17 +170,15 @@ def generate_feature_description_df(
 
     rows = []
 
-    for d in predictor_dicts:
-        column_name = generate_feature_colname(
-            prefix="pred",
-            out_col_name=d["predictor_df"],
-            interval_days=d["lookbehind_days"],
-            resolve_multiple=d["resolve_multiple"],
-            fallback=d["fallback"],
-            loader_kwargs=d.get("loader_kwargs", None),
-        )
+    for spec in predictor_specs:
+        column_name = spec.get_col_str()
 
-        rows.append(generate_feature_description_row(df[column_name], d))
+        rows.append(
+            generate_feature_description_row(
+                series=df[column_name],
+                predictor_spec=spec,
+            ),
+        )
 
     # Convert to dataframe
     feature_description_df = pd.DataFrame(rows)
@@ -159,16 +191,16 @@ def generate_feature_description_df(
 
 def save_feature_description_from_dir(
     feature_set_dir: Path,
-    predictor_dicts: list[dict[str, str]],
+    feature_specs: list[Union[TemporalSpec, StaticSpec]],
     file_suffix: str,
-    splits: tuple[str] = ("train",),
+    splits: Sequence[str] = ("train",),
     out_dir: Path = None,
 ):
     """Write a csv with feature descriptions in the directory.
 
     Args:
         feature_set_dir (Path): Path to directory with data frames.
-        predictor_dicts (list[dict[str, str]]): list of dictionaries with predictor information.
+        feature_specs (list[PredictorSpec]): List of feature specifications.
         file_suffix (str): Suffix of the data frames to load. Must be either ".csv" or ".parquet".
         splits (tuple[str]): tuple of splits to include in the description. Defaults to ("train").
         out_dir (Path): Path to directory where to save the feature description. Defaults to None.
@@ -195,9 +227,10 @@ def save_feature_description_from_dir(
         )
 
         msg.info(f"{split}: Generating feature description dataframe")
+
         feature_description_df = generate_feature_description_df(
             df=predictors,
-            predictor_dicts=predictor_dicts,
+            predictor_specs=feature_specs,
         )
 
         msg.info(f"{split}: Writing feature description to disk")
