@@ -18,7 +18,7 @@ def _load(
     icd_code: Union[list[str], str],
     source_timestamp_col_name: str,
     fct: str,
-    output_col_name: Optional[str] = None,
+    output_col_name_override: Optional[str] = None,
     wildcard_icd_code: Optional[bool] = True,
     n_rows: Optional[int] = None,
 ) -> pd.DataFrame:
@@ -32,8 +32,7 @@ def _load(
         source_timestamp_col_name (str): Name of the timestamp column in the SQL
             view.
         fct (str): Name of the SQL view to load from.
-        output_col_name (str, optional): Name of new column string. Defaults to
-            None.
+        output_col_name_override (str, optional): Name of new column string. If not specified, defaults to the icd_code.
         wildcard_icd_code (bool, optional): Whether to match on icd_code*.
             Defaults to true.
         n_rows: Number of rows to return. Defaults to None.
@@ -86,8 +85,10 @@ def _load(
 
     df = sql_load(sql, database="USR_PS_FORSK", chunksize=None, n_rows=n_rows)
 
-    if output_col_name is None:
+    if output_col_name_override is None:
         output_col_name = icd_code
+    else:
+        output_col_name = output_col_name_override
 
     df[output_col_name] = 1
 
@@ -143,7 +144,7 @@ def concat_from_physical_visits(
     dfs = [
         _load(
             icd_code=icd_codes,
-            output_col_name=output_col_name,
+            output_col_name_override=output_col_name,
             wildcard_icd_code=wildcard_icd_code,
             n_rows=n_rows,
             **kwargs,
@@ -160,7 +161,7 @@ def concat_from_physical_visits(
 
 def from_physical_visits(
     icd_code: str,
-    output_col_name: Optional[str] = "value",
+    output_col_name_override: Optional[str] = "value",
     n_rows: Optional[int] = None,
     wildcard_icd_code: Optional[bool] = False,
 ) -> pd.DataFrame:
@@ -170,7 +171,7 @@ def from_physical_visits(
 
     Args:
         icd_code (str): Substring to match diagnoses for. Matches any diagnoses, whether a-diagnosis, b-diagnosis etc. # noqa: DAR102
-        output_col_name (str, optional): Name of new column string. Defaults to "value".
+        output_col_name_override (str, optional): Name of new column string. Defaults to "value".
         n_rows: Number of rows to return. Defaults to None.
         wildcard_icd_code (bool, optional): Whether to match on icd_code*. Defaults to False.
 
@@ -201,12 +202,12 @@ def from_physical_visits(
     dfs = [
         _load(
             icd_code=icd_code,
-            output_col_name=output_col_name,
+            output_col_name_override=output_col_name_override,
             wildcard_icd_code=wildcard_icd_code,
             n_rows=n_rows_per_df,
             **kwargs,
         )
-        for source_name, kwargs in diagnoses_source_table_info.items()
+        for _, kwargs in diagnoses_source_table_info.items()
     ]
 
     df = pd.concat(dfs).drop_duplicates(
