@@ -195,7 +195,7 @@ def load_all_values(
 def blood_sample(
     blood_sample_id: Union[str, list],
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     """Load a blood sample.
 
@@ -243,7 +243,7 @@ def blood_sample(
 
     for k in sources_to_load:  # pylint: disable=invalid-name
         dfs.append(
-            fn_dict[k](
+            fn_dict[k](  # type: ignore
                 blood_sample_id=blood_sample_id,
                 n_rows=n_rows_per_fn,
                 view=view,
@@ -263,7 +263,9 @@ def blood_sample(
 
 
 @data_loaders.register("hba1c")
-def hba1c(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFrame:
+def hba1c(
+    n_rows: Optional[int] = None, values_to_load: str = "numerical_and_coerce"
+) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU27300",
         n_rows=n_rows,
@@ -274,7 +276,7 @@ def hba1c(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFr
 @data_loaders.register("scheduled_glc")
 def scheduled_glc(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     npu_suffixes = [
         "08550",
@@ -333,7 +335,7 @@ def scheduled_glc(
 @data_loaders.register("unscheduled_p_glc")
 def unscheduled_p_glc(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     npu_suffixes = [
         "02192",
@@ -356,7 +358,7 @@ def unscheduled_p_glc(
 @data_loaders.register("triglycerides")
 def triglycerides(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU04094",
@@ -368,7 +370,7 @@ def triglycerides(
 @data_loaders.register("fasting_triglycerides")
 def fasting_triglycerides(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU03620",
@@ -378,7 +380,9 @@ def fasting_triglycerides(
 
 
 @data_loaders.register("hdl")
-def hdl(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFrame:
+def hdl(
+    n_rows: Optional[int] = None, values_to_load: str = "numerical_and_coerce"
+) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU01567",
         n_rows=n_rows,
@@ -387,7 +391,9 @@ def hdl(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFram
 
 
 @data_loaders.register("ldl")
-def ldl(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFrame:
+def ldl(
+    n_rows: Optional[int] = None, values_to_load: str = "numerical_and_coerce"
+) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id=["NPU01568", "AAB00101"],
         n_rows=n_rows,
@@ -398,7 +404,7 @@ def ldl(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFram
 @data_loaders.register("fasting_ldl")
 def fasting_ldl(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id=["NPU10171", "AAB00102"],
@@ -408,7 +414,9 @@ def fasting_ldl(
 
 
 @data_loaders.register("alat")
-def alat(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFrame:
+def alat(
+    n_rows: Optional[int] = None, values_to_load: str = "numerical_and_coerce"
+) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU19651",
         n_rows=n_rows,
@@ -417,7 +425,9 @@ def alat(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFra
 
 
 @data_loaders.register("asat")
-def asat(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFrame:
+def asat(
+    n_rows: Optional[int] = None, values_to_load: str = "numerical_and_coerce"
+) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU19654",
         n_rows=n_rows,
@@ -428,7 +438,7 @@ def asat(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFra
 @data_loaders.register("lymphocytes")
 def lymphocytes(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU02636",
@@ -440,7 +450,7 @@ def lymphocytes(
 @data_loaders.register("leukocytes")
 def leukocytes(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU02593",
@@ -450,7 +460,9 @@ def leukocytes(
 
 
 @data_loaders.register("crp")
-def crp(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFrame:
+def crp(
+    n_rows: Optional[int] = None, values_to_load: str = "numerical_and_coerce"
+) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU19748",
         n_rows=n_rows,
@@ -461,7 +473,7 @@ def crp(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFram
 @data_loaders.register("creatinine")
 def creatinine(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id=["NPU18016", "ASS00355", "ASS00354"],
@@ -471,7 +483,9 @@ def creatinine(
 
 
 @data_loaders.register("egfr")
-def egfr(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFrame:
+def egfr(
+    n_rows: Optional[int] = None, values_to_load: str = "numerical_and_coerce"
+) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id=["DNK35302", "DNK35131", "AAB00345", "AAB00343"],
         n_rows=n_rows,
@@ -482,7 +496,7 @@ def egfr(n_rows: Optional[int] = None, values_to_load: str = None) -> pd.DataFra
 @data_loaders.register("albumine_creatinine_ratio")
 def albumine_creatinine_ratio(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU19661",
@@ -494,7 +508,7 @@ def albumine_creatinine_ratio(
 @data_loaders.register("cyp21a2")
 def cyp21a2(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU19053",
@@ -506,7 +520,7 @@ def cyp21a2(
 @data_loaders.register("cyp2c19")
 def cyp2c19(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU19309",
@@ -518,7 +532,7 @@ def cyp2c19(
 @data_loaders.register("cyp2c9")
 def cyp2c9(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU32095",
@@ -530,7 +544,7 @@ def cyp2c9(
 @data_loaders.register("cyp3a5")
 def cyp3a5(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU27992",
@@ -542,7 +556,7 @@ def cyp3a5(
 @data_loaders.register("cyp2d6")
 def cyp2d6(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU19308",
@@ -554,7 +568,7 @@ def cyp2d6(
 @data_loaders.register("p_lithium")
 def p_lithium(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU02613",
@@ -566,7 +580,7 @@ def p_lithium(
 @data_loaders.register("p_clozapine")
 def p_clozapine(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU04114",
@@ -578,7 +592,7 @@ def p_clozapine(
 @data_loaders.register("p_olanzapine")
 def p_olanzapine(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU09358",
@@ -590,7 +604,7 @@ def p_olanzapine(
 @data_loaders.register("p_aripiprazol")
 def p_aripiprazol(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU26669",
@@ -602,7 +616,7 @@ def p_aripiprazol(
 @data_loaders.register("p_risperidone")
 def p_risperidone(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU04868",
@@ -614,7 +628,7 @@ def p_risperidone(
 @data_loaders.register("p_paliperidone")
 def p_paliperidone(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU18359",
@@ -626,7 +640,7 @@ def p_paliperidone(
 @data_loaders.register("p_haloperidol")
 def p_haloperidol(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU03937",
@@ -638,7 +652,7 @@ def p_haloperidol(
 @data_loaders.register("p_amitriptyline")
 def p_amitriptyline(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU01224",
@@ -650,7 +664,7 @@ def p_amitriptyline(
 @data_loaders.register("p_nortriptyline")
 def p_nortriptyline(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU02923",
@@ -662,7 +676,7 @@ def p_nortriptyline(
 @data_loaders.register("p_clomipramine")
 def p_clomipramine(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU01616",
@@ -674,7 +688,7 @@ def p_clomipramine(
 @data_loaders.register("p_paracetamol")
 def p_paracetamol(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU03024",
@@ -686,7 +700,7 @@ def p_paracetamol(
 @data_loaders.register("p_ibuprofen")
 def p_ibuprofen(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU08794",
@@ -698,7 +712,7 @@ def p_ibuprofen(
 @data_loaders.register("p_ethanol")
 def p_ethanol(
     n_rows: Optional[int] = None,
-    values_to_load: str = None,
+    values_to_load: str = "numerical_and_coerce",
 ) -> pd.DataFrame:
     return blood_sample(
         blood_sample_id="NPU01992",
