@@ -7,11 +7,11 @@ import catalogue
 from pandas import DataFrame, Series
 from scipy import stats
 
-resolve_fns = catalogue.create("timeseriesflattener", "resolve_strategies")
+resolve_multiple_fns = catalogue.create("timeseriesflattener", "resolve_strategies")
 
 
-@resolve_fns.register("latest")
-def get_latest_value_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("latest")
+def latest(grouped_df: DataFrame) -> DataFrame:
     """Get the latest value.
 
     Args:
@@ -23,8 +23,8 @@ def get_latest_value_in_group(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.last()
 
 
-@resolve_fns.register("earliest")
-def get_earliest_value_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("earliest")
+def earliest(grouped_df: DataFrame) -> DataFrame:
     """Get the earliest value.
 
     Args:
@@ -36,38 +36,38 @@ def get_earliest_value_in_group(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.first()
 
 
-@resolve_fns.register("max")
-def get_max_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("max")
+def maximum(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.max()
 
 
-@resolve_fns.register("min")
-def get_min_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("min")
+def minimum(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.min()
 
 
-@resolve_fns.register("mean")
-def get_mean_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("mean")
+def mean(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.mean(numeric_only=True)
 
 
-@resolve_fns.register("sum")
-def get_sum_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("sum")
+def summed(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.sum()
 
 
-@resolve_fns.register("count")
-def get_count_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("count")
+def count(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.count()
 
 
-@resolve_fns.register("variance")
-def get_variance_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("variance")
+def variance(grouped_df: DataFrame) -> DataFrame:
     return grouped_df.var()
 
 
-@resolve_fns.register("bool")
-def get_bool_in_group(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("bool")
+def boolean(grouped_df: DataFrame) -> DataFrame:
     """Returns a boolean value indicating whether or not event has occured in
     look ahead/behind window.
 
@@ -77,13 +77,19 @@ def get_bool_in_group(grouped_df: DataFrame) -> DataFrame:
     Returns:
         DataFrame: Dataframe with value column containing only 0 or 1s.
     """
-    grouped_df = grouped_df.count().reset_index()
-    grouped_df[grouped_df["value"] > 0] = grouped_df.assign(value=1)
+    grouped_df = (
+        grouped_df["timestamp_val"]
+        .apply(lambda x: (~x.isna()).sum())
+        .reset_index(name="value")
+    )
+
+    grouped_df.loc[grouped_df["value"] > 0, "value"] = 1
+
     return grouped_df
 
 
-@resolve_fns.register("change_per_day")
-def get_change_in_value_per_day(grouped_df: DataFrame) -> DataFrame:
+@resolve_multiple_fns.register("change_per_day")
+def change_per_day(grouped_df: DataFrame) -> DataFrame:
     """Returns the change in value per day.
 
     Args:
